summaryrefslogtreecommitdiffstats
path: root/kbabel/datatools/whitespace/main.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/datatools/whitespace/main.cc')
-rw-r--r--kbabel/datatools/whitespace/main.cc28
1 files changed, 14 insertions, 14 deletions
diff --git a/kbabel/datatools/whitespace/main.cc b/kbabel/datatools/whitespace/main.cc
index 882815a5..7bfa50b2 100644
--- a/kbabel/datatools/whitespace/main.cc
+++ b/kbabel/datatools/whitespace/main.cc
@@ -54,13 +54,13 @@ K_EXPORT_COMPONENT_FACTORY( kbabel_whitespacetool, KGenericFactory<WhitespaceToo
using namespace KBabel;
-WhitespaceTool::WhitespaceTool( QObject* parent, const char* name, const QStringList & )
+WhitespaceTool::WhitespaceTool( TQObject* parent, const char* name, const TQStringList & )
: KDataTool( parent, name ), _cache_origin( 0 ), _equation("^[a-zA-Z0-9]+=")
{
i18n("which check found errors","whitespace only translation");
}
-bool WhitespaceTool::run( const QString& command, void* data, const QString& datatype, const QString& mimetype )
+bool WhitespaceTool::run( const TQString& command, void* data, const TQString& datatype, const TQString& mimetype )
{
if ( command != "validate" )
@@ -89,8 +89,8 @@ bool WhitespaceTool::run( const QString& command, void* data, const QString& dat
CatalogItem* item = (CatalogItem*)(data);
bool hasIdError = false;
bool hasStrError = false;
- QRegExp _whitespace("^\\s+$");
- QStringList str, id;
+ TQRegExp _whitespace("^\\s+$");
+ TQStringList str, id;
if(!item->isUntranslated()) {
if( _cache_origin != item->project() )
@@ -102,28 +102,28 @@ bool WhitespaceTool::run( const QString& command, void* data, const QString& dat
//Ensure KDE plural forms are in a StringList
//FIXME Eliminate context information and this could become a generic message splitter
if( item->pluralForm() == KDESpecific ) {
- str = QStringList::split( "\\n", item->msgstr().first(), true );
- id = QStringList::split( "\\n",
- item->msgid().first().replace( QRegExp(_plurals), ""), true );
+ str = TQStringList::split( "\\n", item->msgstr().first(), true );
+ id = TQStringList::split( "\\n",
+ item->msgid().first().replace( TQRegExp(_plurals), ""), true );
} else {
str = item->msgstr();
id = item->msgid();
}
//Strip equations
- id.first().replace( QRegExp(_equation), "");
- str.first().replace( QRegExp(_equation), "");
+ id.first().replace( TQRegExp(_equation), "");
+ str.first().replace( TQRegExp(_equation), "");
//Ignore Messages with blank msgid components
- for( QStringList::Iterator it = id.begin() ; it != id.end() ; it++ ) {
- QString resultstring = (*it);
+ for( TQStringList::Iterator it = id.begin() ; it != id.end() ; it++ ) {
+ TQString resultstring = (*it);
hasIdError = hasIdError || resultstring.contains(_whitespace);
}
if( hasIdError ) return true;
- //Check each QString in the List is not whitespace
- for( QStringList::Iterator it = str.begin() ; it != str.end() ; it++ ) {
- QString resultstring = (*it);
+ //Check each TQString in the List is not whitespace
+ for( TQStringList::Iterator it = str.begin() ; it != str.end() ; it++ ) {
+ TQString resultstring = (*it);
hasStrError = hasStrError || resultstring.contains(_whitespace);
}